@@ -16,43 +16,12 @@ from zyte_api.aio.errors import RequestError
 from zyte_api.apikey import NoApiKey
 from zyte_api.constants import API_URL
 
-from ._params import _get_api_params
+from ._params import _ParamParser
 from .responses import ZyteAPIResponse, ZyteAPITextResponse, _process_response
 
 logger = logging.getLogger(__name__)
 
 
-def _load_default_params(settings, setting):
-    params = settings.getdict(setting)
-    for param in list(params):
-        if params[param] is not None:
-            continue
-        logger.warning(
-            f"Parameter {param!r} in the {setting} setting is None. Default "
-            f"parameters should never be None."
-        )
-        params.pop(param)
-    return params
-
-
-def _load_skip_headers(settings):
-    return {
-        header.strip().lower().encode()
-        for header in settings.getlist(
-            "ZYTE_API_SKIP_HEADERS",
-            ["Cookie", "User-Agent"],
-        )
-    }
-
-
-def _load_browser_headers(settings):
-    browser_headers = settings.getdict(
-        "ZYTE_API_BROWSER_HEADERS",
-        {"Referer": "referer"},
-    )
-    return {k.strip().lower().encode(): v for k, v in browser_headers.items()}
-
-
 def _load_retry_policy(settings):
     policy = settings.get("ZYTE_API_RETRY_POLICY")
     if policy:
@@ -91,27 +60,13 @@ class ScrapyZyteAPIDownloadHandler(HTTPDownloadHandler):
         verify_installed_reactor(
             "twisted.internet.asyncioreactor.AsyncioSelectorReactor"
         )
+        self._param_parser = _ParamParser(settings)
+        self._retry_policy = _load_retry_policy(settings)
         self._stats = crawler.stats
         self._session = create_session(connection_pool_size=self._client.n_conn)
 
-        self._automap_params = _load_default_params(settings, "ZYTE_API_AUTOMAP_PARAMS")
-        self._browser_headers = _load_browser_headers(settings)
-        self._default_params = _load_default_params(settings, "ZYTE_API_DEFAULT_PARAMS")
-        self._job_id = crawler.settings.get("JOB")
-        self._retry_policy = _load_retry_policy(settings)
-        self._transparent_mode = settings.getbool("ZYTE_API_TRANSPARENT_MODE", False)
-        self._skip_headers = _load_skip_headers(settings)
-
     def download_request(self, request: Request, spider: Spider) -> Deferred:
-        api_params = _get_api_params(
-            request,
-            default_params=self._default_params,
-            transparent_mode=self._transparent_mode,
-            automap_params=self._automap_params,
-            skip_headers=self._skip_headers,
-            browser_headers=self._browser_headers,
-            job_id=self._job_id,
-        )
+        api_params = self._param_parser.parse(request)
         if api_params is not None:
             return deferred_from_coro(
                 self._download_request(api_params, request, spider)
@@ -167,7 +122,6 @@ class ScrapyZyteAPIDownloadHandler(HTTPDownloadHandler):
         self, api_params: dict, request: Request, spider: Spider
     ) -> Optional[Union[ZyteAPITextResponse, ZyteAPIResponse]]:
         # Define url by default
-        api_data = {**{"url": request.url}, **api_params}
         retrying = request.meta.get("zyte_api_retry_policy")
         if retrying:
             retrying = load_object(retrying)
@@ -175,7 +129,7 @@ class ScrapyZyteAPIDownloadHandler(HTTPDownloadHandler):
             retrying = self._retry_policy
         try:
             api_response = await self._client.request_raw(
-                api_data,
+                api_params,
                 session=self._session,
                 retrying=retrying,
             )
